==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/DataProvider.java <==
package com.example.model;

/**
 * Model for DataConnect
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.328Z")
@io.swagger.annotations.ApiModel(value = "DataProvider", description = "Model for DataConnect")
@javax.xml.bind.annotation.XmlRootElement(name = "DataProvider")
public class DataProvider implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private com.example.model.DataConnectData data = null;
	private java.lang.String message = null;
	private java.lang.String overall = null;
	private java.lang.String version = null;
	private java.lang.Boolean xml = null;
	
	/**
	 * Model for DataConnectData
	 */
	public DataProvider data(com.example.model.DataConnectData data) {
		setData(data);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "Model for DataConnectData")
	@com.fasterxml.jackson.annotation.JsonProperty("data")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public com.example.model.DataConnectData getData() {
		return this.data;
	}
	public void setData(com.example.model.DataConnectData data) {
		this.data = data;
	}
	
	/**
	 */
	public DataProvider message(java.lang.String message) {
		setMessage(message);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("message")
	public java.lang.String getMessage() {
		return this.message;
	}
	public void setMessage(java.lang.String message) {
		this.message = message;
	}
	
	/**
	 */
	public DataProvider overall(java.lang.String overall) {
		setOverall(overall);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("overall")
	public java.lang.String getOverall() {
		return this.overall;
	}
	public void setOverall(java.lang.String overall) {
		this.overall = overall;
	}
	
	/**
	 */
	public DataProvider version(java.lang.String version) {
		setVersion(version);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("version")
	public java.lang.String getVersion() {
		return this.version;
	}
	public void setVersion(java.lang.String version) {
		this.version = version;
	}
	
	/**
	 */
	public DataProvider xml(java.lang.Boolean xml) {
		setXml(xml);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("xml")
	public java.lang.Boolean getXml() {
		return this.xml;
	}
	public void setXml(java.lang.Boolean xml) {
		this.xml = xml;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		DataProvider dataProvider = (DataProvider) o;
		return java.util.Objects.equals(this.data, dataProvider.data)
				&& java.util.Objects.equals(this.message, dataProvider.message)
				&& java.util.Objects.equals(this.overall, dataProvider.overall)
				&& java.util.Objects.equals(this.version, dataProvider.version)
				&& java.util.Objects.equals(this.xml, dataProvider.xml);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.data, this.message, this.overall, this.version, this.xml);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class DataProvider {\n");
		
		sb.append("    data: ").append(toIndentedString(this.data)).append("\n");
		sb.append("    message: ").append(toIndentedString(this.message)).append("\n");
		sb.append("    overall: ").append(toIndentedString(this.overall)).append("\n");
		sb.append("    version: ").append(toIndentedString(this.version)).append("\n");
		sb.append("    xml: ").append(toIndentedString(this.xml)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/DataProvider.java <==
package com.example.model;

/**
 * Model for DataConnect
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.431Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "DataProvider", description = "Model for DataConnect")
@javax.xml.bind.annotation.XmlRootElement(name = "DataProvider")
public class DataProvider implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private com.example.model.DataConnectData data = null;
	private java.lang.String message = null;
	private java.lang.String overall = null;
	private java.lang.String version = null;
	private java.lang.Boolean xml = null;
	
	/**
	 * Model for DataConnectData
	 */
	public DataProvider data(com.example.model.DataConnectData data) {
		setData(data);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "data", description = "Model for DataConnectData")
	@com.fasterxml.jackson.annotation.JsonProperty("data")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public com.example.model.DataConnectData getData() {
		return this.data;
	}
	public void setData(com.example.model.DataConnectData data) {
		this.data = data;
	}
	
	/**
	 */
	public DataProvider message(java.lang.String message) {
		setMessage(message);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "message")
	@com.fasterxml.jackson.annotation.JsonProperty("message")
	public java.lang.String getMessage() {
		return this.message;
	}
	public void setMessage(java.lang.String message) {
		this.message = message;
	}
	
	/**
	 */
	public DataProvider overall(java.lang.String overall) {
		setOverall(overall);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "overall")
	@com.fasterxml.jackson.annotation.JsonProperty("overall")
	public java.lang.String getOverall() {
		return this.overall;
	}
	public void setOverall(java.lang.String overall) {
		this.overall = overall;
	}
	
	/**
	 */
	public DataProvider version(java.lang.String version) {
		setVersion(version);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "version")
	@com.fasterxml.jackson.annotation.JsonProperty("version")
	public java.lang.String getVersion() {
		return this.version;
	}
	public void setVersion(java.lang.String version) {
		this.version = version;
	}
	
	/**
	 */
	public DataProvider xml(java.lang.Boolean xml) {
		setXml(xml);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "xml")
	@com.fasterxml.jackson.annotation.JsonProperty("xml")
	public java.lang.Boolean getXml() {
		return this.xml;
	}
	public void setXml(java.lang.Boolean xml) {
		this.xml = xml;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		DataProvider dataProvider = (DataProvider) o;
		return java.util.Objects.equals(this.data, dataProvider.data)
				&& java.util.Objects.equals(this.message, dataProvider.message)
				&& java.util.Objects.equals(this.overall, dataProvider.overall)
				&& java.util.Objects.equals(this.version, dataProvider.version)
				&& java.util.Objects.equals(this.xml, dataProvider.xml);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.data, this.message, this.overall, this.version, this.xml);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class DataProvider {\n");
		
		sb.append("    data: ").append(toIndentedString(this.data)).append("\n");
		sb.append("    message: ").append(toIndentedString(this.message)).append("\n");
		sb.append("    overall: ").append(toIndentedString(this.overall)).append("\n");
		sb.append("    version: ").append(toIndentedString(this.version)).append("\n");
		sb.append("    xml: ").append(toIndentedString(this.xml)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
